;; Generated package description from smalltalk-mode.el  -*- no-byte-compile: t -*-
(define-package "smalltalk-mode" "4.0.0.20221212.220106" "Major mode for the GNU Smalltalk programming language" 'nil :commit "744fed873ca8ab8b4acc2e53fbc296819bdab1af" :url "https://elpa.gnu.org/packages/smalltalk-mode.html" :authors '(("Steve Byrne")) :maintainer '("Derek Zhou" . "derek@3qin.us"))
